package mvc.gui;

import mvc.model.Counter;
import mvc.model.CounterListener;

/**
 * View frame (window) showing the count in a given radix.
 * It listens to the model, but does not know what model
 * it listens to.
 * 
 * @author wstomv
 */
public class ViewFrame extends javax.swing.JFrame implements CounterListener {

    /**
     * Creates new form ViewFrame
     */
    public ViewFrame(final int count, final int radix) {
        initComponents();
        this.radix = radix;
        jTextFieldCount.setText(Integer.toString(count, radix));
        this.setTitle("View in radix " + radix);
        setVisible(true);
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jPanelView = new javax.swing.JPanel();
        jLabelCount = new javax.swing.JLabel();
        jTextFieldCount = new javax.swing.JTextField();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setTitle("View");

        jPanelView.setBorder(javax.swing.BorderFactory.createEtchedBorder());
        jPanelView.setToolTipText("View");

        jLabelCount.setFont(new java.awt.Font("Lucida Grande", 0, 18)); // NOI18N
        jLabelCount.setHorizontalAlignment(javax.swing.SwingConstants.CENTER);
        jLabelCount.setText("Count");

        jTextFieldCount.setEditable(false);
        jTextFieldCount.setColumns(2);
        jTextFieldCount.setFont(new java.awt.Font("Lucida Grande", 0, 18)); // NOI18N
        jTextFieldCount.setHorizontalAlignment(javax.swing.JTextField.CENTER);
        jTextFieldCount.setText("0");
        jTextFieldCount.setToolTipText("The current count");

        org.jdesktop.layout.GroupLayout jPanelViewLayout = new org.jdesktop.layout.GroupLayout(jPanelView);
        jPanelView.setLayout(jPanelViewLayout);
        jPanelViewLayout.setHorizontalGroup(
            jPanelViewLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanelViewLayout.createSequentialGroup()
                .addContainerGap()
                .add(jLabelCount, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 74, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jTextFieldCount, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 117, Short.MAX_VALUE)
                .addContainerGap())
        );
        jPanelViewLayout.setVerticalGroup(
            jPanelViewLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanelViewLayout.createSequentialGroup()
                .addContainerGap()
                .add(jPanelViewLayout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jTextFieldCount, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                    .add(jLabelCount))
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanelView, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanelView, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel jLabelCount;
    private javax.swing.JPanel jPanelView;
    private javax.swing.JTextField jTextFieldCount;
    // End of variables declaration//GEN-END:variables
    
    /**
     * The radix for viewing the count.
     * {@code Character.MAX_RADIX <= radix <= Character.MIN_RADIX} */
    private int radix;
    
    /** Update this frame, both controller and view. */
    private void updatePanel() {
        repaint();
    }
    
    /**
     * Respond to change event from model.
     * 
     * @param newCount  the updated value
     */
    @Override
    public void counterChanged(final int newCount) {
        jTextFieldCount.setText(Integer.toString(newCount, radix));
        updatePanel();
    }
    
}
