package mvc.model;

import mvc.model.Counter;
import mvc.model.CounterListener;
import junit.framework.TestCase;

/**
 * Test cases for class Counter.
 * 
 * @author Tom Verhoeff (TU/e)
 */
public class CounterTest extends TestCase {
    
    public CounterTest(String testName) {
        super(testName);
    }

    /**
     * Test of getCount method, of class Counter.
     */
    public void testGetCount() {
        System.out.println("getCount");
        Counter instance = new Counter();
        int expResult = 0;
        int result = instance.getCount();
        assertEquals("Initial state", expResult, result);
    }

    /**
     * Test of reset method, of class Counter.
     */
    public void testReset() {
        System.out.println("reset");
        Counter instance = new Counter();
        {
            instance.reset();
            int expResult = 0;
            int result = instance.getCount();
            assertEquals("Initial state", expResult, result);
        }
        {
            instance.increment();
            instance.reset();
            int expResult = 0;
            int result = instance.getCount();
            assertEquals("After increment, reset", expResult, result);
        }
    }

    /**
     * Test of increment method, of class Counter.
     */
    public void testIncrement() {
        System.out.println("increment");
        Counter instance = new Counter();
        instance.increment();
        int expResult = 1;
        int result = instance.getCount();
        assertEquals("After increment", expResult, result);
    }
    
    /**
     * Tests with observer without change, of class Counter.
     */
    public void testObserverNoChange() {
        System.out.println("Counter with observer, no change");
        
        // No event expected
        Counter instance = new Counter();
        instance.addListener(new CounterListener() {
            @Override
            public void counterChanged(int newCount) {
                fail("Unexpected counterChanged call");
            }
        });
        instance.reset(); // does not change the count
        assertTrue("counterChanged not called", true);
    }
    
    /**
     * Tests with observer with change, of class Counter.
     */
    public void testObserverWithChange() {
        System.out.println("Counter with observer, with change");
        
        final int expCount = 1; // expected count after increment
        // Event expected
        class MyCounterListener implements CounterListener {

            public boolean called = false;

            @Override
            public void counterChanged(int newCount) {
                called = true;
                assertEquals("counterChanged newCount", expCount, newCount);
            }
        }
        MyCounterListener listener = new MyCounterListener();
        Counter instance = new Counter();
        instance.addListener(listener);
        instance.increment();
        assertEquals("counterChanged called", true, listener.called);
    }

}
